@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,9 +12,7 @@ ImportExportProgressIndicatorConsole::ImportExportProgressIndicatorConsole(QObje
 {
 }
 
-ImportExportProgressIndicatorConsole::~ImportExportProgressIndicatorConsole()
-{
-}
+ImportExportProgressIndicatorConsole::~ImportExportProgressIndicatorConsole() = default;
 
 void ImportExportProgressIndicatorConsole::setProgressDialogLabel(const QString &text)
 {
