@@ -28,6 +28,7 @@ class PIMDATAEXPORTER_EXPORT AbstractImportExportJob : public QObject
 {
     Q_OBJECT
 public:
+    friend class ImportMailFolderAttributeJob;
     explicit AbstractImportExportJob(QObject *parent, ArchiveStorage *archiveStorage, Utils::StoredTypes typeSelected, int numberOfStep);
     ~AbstractImportExportJob() override;
 
@@ -52,19 +53,23 @@ Q_SIGNALS:
     void endLine();
     void needSynchronizeResource(const QString &name, const QString &identifier);
     void jobFinished();
+    void exportAttributeDone();
 
 protected:
     virtual void slotNextStep();
 
 protected:
-    bool copyArchiveFileTo(const KArchiveFile *file, const QString &destination);
+    void emitInfo(const QString &str);
+    void emitError(const QString &str);
+    virtual QString applicationName() const = 0;
+    Q_REQUIRED_RESULT QString generateInfo(const QString &info);
     void initializeListStep();
     virtual void startSynchronizeResources(const QStringList &listResourceToSync);
     void infoAboutNewResource(const QString &resourceName);
     void copyToDirectory(const KArchiveEntry *entry, const QString &dest);
     void extractZipFile(const KArchiveFile *file, const QString &source, const QString &destination, bool isStoredAsZippedArchive = true);
 
-    Q_REQUIRED_RESULT qint64 convertRealPathToCollection(KConfigGroup &group, const QString &currentKey, bool addCollectionPrefix = false);
+    qint64 convertRealPathToCollection(KConfigGroup &group, const QString &currentKey, bool addCollectionPrefix = false);
     void copyToFile(const KArchiveFile *archivefile, const QString &dest, const QString &filename, const QString &prefix);
     void initializeImportJob();
     void backupFile(const QString &filename, const QString &path, const QString &storedName);
@@ -74,7 +79,6 @@ protected:
 
     Q_REQUIRED_RESULT int mergeConfigMessageBox(const QString &configName) const;
     Q_REQUIRED_RESULT bool overwriteConfigMessageBox(const QString &configName) const;
-    Q_REQUIRED_RESULT Akonadi::Collection::Id convertPathToId(const QString &path);
 
     void backupResourceFile(const QString &agentIdentifier, const QString &defaultPath);
 
@@ -90,6 +94,9 @@ protected:
     void searchAllFiles(const KArchiveDirectory *dir, const QString &prefix, const QString &searchEntryName);
     void storeArchiveInfoResources(const KArchiveDirectory *dir, const QString &prefix);
 
+    bool copyArchiveFileTo(const KArchiveFile *file, const QString &destination);
+    Q_REQUIRED_RESULT Akonadi::Collection::Id convertPathToId(const QString &path);
+
     Q_REQUIRED_RESULT KZip *archive() const;
 
     void increaseProgressDialog();
