@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -22,9 +22,7 @@ ImportAkregatorJobInterface::ImportAkregatorJobInterface(QObject *parent, Utils:
     initializeImportJob();
 }
 
-ImportAkregatorJobInterface::~ImportAkregatorJobInterface()
-{
-}
+ImportAkregatorJobInterface::~ImportAkregatorJobInterface() = default;
 
 void ImportAkregatorJobInterface::start()
 {
@@ -37,6 +35,7 @@ void ImportAkregatorJobInterface::start()
 
 Akonadi::Collection::Id ImportAkregatorJobInterface::convertFolderPathToCollectionId(const QString &path)
 {
+    Q_UNUSED(path);
     Q_UNREACHABLE();
     // Unused here.
     return -1;
@@ -45,12 +44,25 @@ Akonadi::Collection::Id ImportAkregatorJobInterface::convertFolderPathToCollecti
 QString
 ImportAkregatorJobInterface::createResource(const QString &resources, const QString &name, const QMap<QString, QVariant> &settings, bool synchronizeTree)
 {
+    Q_UNUSED(resources);
+    Q_UNUSED(name);
+    Q_UNUSED(settings);
+    Q_UNUSED(synchronizeTree);
+
     Q_UNREACHABLE();
     return {};
 }
 
+QString ImportAkregatorJobInterface::applicationName() const
+{
+    return QStringLiteral("[Akregator]");
+}
+
 QString ImportAkregatorJobInterface::adaptNewResourceUrl(bool overwriteResources, const KSharedConfig::Ptr &resourceConfig, const QString &storePath)
 {
+    Q_UNUSED(overwriteResources);
+    Q_UNUSED(resourceConfig);
+    Q_UNUSED(storePath);
     Q_UNREACHABLE();
     // Unused
     return {};
@@ -84,7 +96,7 @@ void ImportAkregatorJobInterface::restoreConfig()
     restoreUiRcFile(QStringLiteral("akregator_shell.rc"), QStringLiteral("akregator"));
     restoreConfigFile(QStringLiteral("akregator.notifyrc"));
 
-    Q_EMIT info(i18n("Config restored."));
+    emitInfo(i18n("Config restored."));
     QTimer::singleShot(0, this, &ImportAkregatorJobInterface::slotNextStep);
 }
 
@@ -97,6 +109,6 @@ void ImportAkregatorJobInterface::restoreData()
         const QString akregatorPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + QStringLiteral("akregator/");
         overwriteDirectory(akregatorPath, akregatorEntry);
     }
-    Q_EMIT info(i18n("Data restored."));
+    emitInfo(i18n("Data restored."));
     QTimer::singleShot(0, this, &ImportAkregatorJobInterface::slotNextStep);
 }
