@@ -8,6 +8,7 @@
 
 #include <QTemporaryFile>
 #include <QTextStream>
+#include <QVariant>
 
 //#define REMOVE_TEMPORARY_FILE 1
 
@@ -24,9 +25,7 @@ LogCreatingResource::LogCreatingResource(QObject *parent)
     // qDebug() << " mTmpLogFile*************" << mTmpLogFile->fileName();
 }
 
-LogCreatingResource::~LogCreatingResource()
-{
-}
+LogCreatingResource::~LogCreatingResource() = default;
 
 void LogCreatingResource::appendText(const QString &str)
 {
