@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -28,9 +28,7 @@ ImportCalendarJobInterface::ImportCalendarJobInterface(QObject *parent, Utils::S
     initializeImportJob();
 }
 
-ImportCalendarJobInterface::~ImportCalendarJobInterface()
-{
-}
+ImportCalendarJobInterface::~ImportCalendarJobInterface() = default;
 
 void ImportCalendarJobInterface::start()
 {
@@ -82,9 +80,8 @@ bool ImportCalendarJobInterface::isAConfigFile(const QString &name) const
 {
     return name.endsWith(QLatin1String("rc"))
         && (name.contains(QLatin1String("akonadi_ical_resource_")) || name.contains(QLatin1String("akonadi_davgroupware_resource_"))
-            || name.contains(QLatin1String("akonadi_icaldir_resource_"))
-             || name.contains(QLatin1String("akonadi_openxchange_resource_"))
-             || name.contains(QLatin1String("akonadi_google_resource_")));
+            || name.contains(QLatin1String("akonadi_icaldir_resource_")) || name.contains(QLatin1String("akonadi_openxchange_resource_"))
+            || name.contains(QLatin1String("akonadi_google_resource_")));
 }
 
 void ImportCalendarJobInterface::restoreConfig()
@@ -119,82 +116,108 @@ void ImportCalendarJobInterface::restoreConfig()
         }
     }
 
-    const QString korganizerStr(QStringLiteral("korganizerrc"));
-    const KArchiveEntry *korganizerrcentry = mArchiveDirectory->entry(Utils::configsPath() + korganizerStr);
-    if (korganizerrcentry && korganizerrcentry->isFile()) {
-        const auto korganizerrcFile = static_cast<const KArchiveFile *>(korganizerrcentry);
-        const QString korganizerrc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + korganizerStr;
-        if (QFileInfo::exists(korganizerrc)) {
-            if (overwriteConfigMessageBox(korganizerStr)) {
+    {
+        const QString korganizerStr(QStringLiteral("korganizerrc"));
+        const KArchiveEntry *korganizerrcentry = mArchiveDirectory->entry(Utils::configsPath() + korganizerStr);
+        if (korganizerrcentry && korganizerrcentry->isFile()) {
+            const auto korganizerrcFile = static_cast<const KArchiveFile *>(korganizerrcentry);
+            const QString korganizerrc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + korganizerStr;
+            if (QFileInfo::exists(korganizerrc)) {
+                if (overwriteConfigMessageBox(korganizerStr)) {
+                    importkorganizerConfig(korganizerrcFile, korganizerrc, korganizerStr, Utils::configsPath());
+                }
+            } else {
                 importkorganizerConfig(korganizerrcFile, korganizerrc, korganizerStr, Utils::configsPath());
             }
-        } else {
-            importkorganizerConfig(korganizerrcFile, korganizerrc, korganizerStr, Utils::configsPath());
         }
     }
 
-    const QString eventviewStr(QStringLiteral("eventviewsrc"));
-    const KArchiveEntry *eventviewentry = mArchiveDirectory->entry(Utils::configsPath() + eventviewStr);
-    if (eventviewentry && eventviewentry->isFile()) {
-        const auto eventviewrcFile = static_cast<const KArchiveFile *>(eventviewentry);
-        const QString eventviewrc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + eventviewStr;
-        if (QFileInfo::exists(eventviewrc)) {
-            if (overwriteConfigMessageBox(eventviewStr)) {
+    {
+        const QString eventviewStr(QStringLiteral("eventviewsrc"));
+        const KArchiveEntry *eventviewentry = mArchiveDirectory->entry(Utils::configsPath() + eventviewStr);
+        if (eventviewentry && eventviewentry->isFile()) {
+            const auto eventviewrcFile = static_cast<const KArchiveFile *>(eventviewentry);
+            const QString eventviewrc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + eventviewStr;
+            if (QFileInfo::exists(eventviewrc)) {
+                if (overwriteConfigMessageBox(eventviewStr)) {
+                    importeventViewConfig(eventviewrcFile, eventviewrc, eventviewStr, Utils::configsPath());
+                }
+            } else {
                 importeventViewConfig(eventviewrcFile, eventviewrc, eventviewStr, Utils::configsPath());
             }
-        } else {
-            importeventViewConfig(eventviewrcFile, eventviewrc, eventviewStr, Utils::configsPath());
         }
     }
-
-    const QString korgacStr(QStringLiteral("korgacrc"));
-    const KArchiveEntry *korgacrcentry = mArchiveDirectory->entry(Utils::configsPath() + korgacStr);
-    if (korgacrcentry && korgacrcentry->isFile()) {
-        const auto korgacrcFile = static_cast<const KArchiveFile *>(korgacrcentry);
-        const QString korgacrc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + korgacStr;
-        if (QFileInfo::exists(korgacrc)) {
-            if (overwriteConfigMessageBox(korgacStr)) {
-                copyToFile(korgacrcFile, korgacrc, korgacStr, Utils::configsPath());
+    {
+        const QString kalendaracStr(QStringLiteral("kalendaracrc"));
+        const KArchiveEntry *kalendaracentry = mArchiveDirectory->entry(Utils::configsPath() + kalendaracStr);
+        if (kalendaracentry && kalendaracentry->isFile()) {
+            const auto kalendaracFile = static_cast<const KArchiveFile *>(kalendaracentry);
+            const QString kalendaracrc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + kalendaracStr;
+            if (QFileInfo::exists(kalendaracrc)) {
+                if (overwriteConfigMessageBox(kalendaracStr)) {
+                    copyToFile(kalendaracFile, kalendaracrc, kalendaracStr, Utils::configsPath());
+                }
+            } else {
+                copyToFile(kalendaracFile, kalendaracrc, kalendaracStr, Utils::configsPath());
+            }
+        }
+    }
+    {
+        const QString kalendarStr(QStringLiteral("kalendarrc"));
+        const KArchiveEntry *kalendarentry = mArchiveDirectory->entry(Utils::configsPath() + kalendarStr);
+        if (kalendarentry && kalendarentry->isFile()) {
+            const auto kalendarentryFile = static_cast<const KArchiveFile *>(kalendarentry);
+            const QString kalendarentrycrc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + kalendarStr;
+            if (QFileInfo::exists(kalendarentrycrc)) {
+                if (overwriteConfigMessageBox(kalendarStr)) {
+                    importKalendarConfig(kalendarentryFile, kalendarentrycrc, kalendarStr, Utils::configsPath());
+                }
+            } else {
+                importKalendarConfig(kalendarentryFile, kalendarentrycrc, kalendarStr, Utils::configsPath());
             }
-        } else {
-            copyToFile(korgacrcFile, korgacrc, korgacStr, Utils::configsPath());
         }
     }
 
-    const QString freebusyStr(QStringLiteral("freebusyurls"));
-    const KArchiveEntry *freebusyentry = mArchiveDirectory->entry(Utils::dataPath() + QLatin1String("korganizer/") + freebusyStr);
-    if (freebusyentry && freebusyentry->isFile()) {
-        const auto freebusyrcFile = static_cast<const KArchiveFile *>(freebusyentry);
+    {
+        const QString freebusyStr(QStringLiteral("freebusyurls"));
+        const KArchiveEntry *freebusyentry = mArchiveDirectory->entry(Utils::dataPath() + QLatin1String("korganizer/") + freebusyStr);
+        if (freebusyentry && freebusyentry->isFile()) {
+            const auto freebusyrcFile = static_cast<const KArchiveFile *>(freebusyentry);
 
-        const QString freebusypath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/korganizer/") + freebusyStr;
-        if (QFileInfo::exists(freebusypath)) {
-            // TODO 4.12 merge it.
-            if (overwriteConfigMessageBox(freebusyStr)) {
+            const QString freebusypath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/korganizer/") + freebusyStr;
+            if (QFileInfo::exists(freebusypath)) {
+                // TODO 4.12 merge it.
+                if (overwriteConfigMessageBox(freebusyStr)) {
+                    copyToFile(freebusyrcFile, freebusypath, freebusyStr, Utils::dataPath());
+                }
+            } else {
                 copyToFile(freebusyrcFile, freebusypath, freebusyStr, Utils::dataPath());
             }
-        } else {
-            copyToFile(freebusyrcFile, freebusypath, freebusyStr, Utils::dataPath());
         }
     }
 
-    const KArchiveEntry *templateEntry = mArchiveDirectory->entry(Utils::dataPath() + QStringLiteral("korganizer/templates/"));
-    if (templateEntry && templateEntry->isDirectory()) {
-        // TODO 4.12 verify if template already exists.
-        const QString templatePath =
-            QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + QStringLiteral("korganizer/templates/");
-        const auto templateDir = static_cast<const KArchiveDirectory *>(templateEntry);
-        if (!templateDir->copyTo(templatePath)) {
-            qCDebug(PIMDATAEXPORTERCORE_LOG) << "template cannot copy to " << templatePath;
+    {
+        const KArchiveEntry *templateEntry = mArchiveDirectory->entry(Utils::dataPath() + QStringLiteral("korganizer/templates/"));
+        if (templateEntry && templateEntry->isDirectory()) {
+            // TODO 4.12 verify if template already exists.
+            const QString templatePath =
+                QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + QStringLiteral("korganizer/templates/");
+            const auto templateDir = static_cast<const KArchiveDirectory *>(templateEntry);
+            if (!templateDir->copyTo(templatePath)) {
+                qCDebug(PIMDATAEXPORTERCORE_LOG) << "template cannot copy to " << templatePath;
+            }
         }
     }
 
-    const KArchiveEntry *designerEntry = mArchiveDirectory->entry(Utils::dataPath() + QStringLiteral("korganizer/designer/"));
-    if (designerEntry && designerEntry->isDirectory()) {
-        const QString templatePath =
-            QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + QStringLiteral("korganizer/designer/");
-        const auto templateDir = static_cast<const KArchiveDirectory *>(designerEntry);
-        if (!templateDir->copyTo(templatePath)) {
-            qCDebug(PIMDATAEXPORTERCORE_LOG) << "template cannot copy to " << templatePath;
+    {
+        const KArchiveEntry *designerEntry = mArchiveDirectory->entry(Utils::dataPath() + QStringLiteral("korganizer/designer/"));
+        if (designerEntry && designerEntry->isDirectory()) {
+            const QString templatePath =
+                QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + QStringLiteral("korganizer/designer/");
+            const auto templateDir = static_cast<const KArchiveDirectory *>(designerEntry);
+            if (!templateDir->copyTo(templatePath)) {
+                qCDebug(PIMDATAEXPORTERCORE_LOG) << "template cannot copy to " << templatePath;
+            }
         }
     }
 
@@ -202,7 +225,7 @@ void ImportCalendarJobInterface::restoreConfig()
     restoreUiRcFile(QStringLiteral("korganizer_part.rc"), QStringLiteral("korganizer"));
 
     restoreConfigFile(QStringLiteral("eventviewsrc"));
-    Q_EMIT info(i18n("Config restored."));
+    emitInfo(i18n("Config restored."));
     QTimer::singleShot(0, this, &ImportCalendarJobInterface::slotNextStep);
 }
 
@@ -218,14 +241,29 @@ void ImportCalendarJobInterface::importkorganizerConfig(const KArchiveFile *file
     korganizerConfig->sync();
 }
 
+void ImportCalendarJobInterface::importKalendarConfig(const KArchiveFile *file, const QString &config, const QString &filename, const QString &prefix)
+{
+    copyToFile(file, config, filename, prefix);
+    KSharedConfig::Ptr kalendarConfig = KSharedConfig::openConfig(config);
+
+    convertCollectionListStrToAkonadiId(kalendarConfig, QStringLiteral("GlobalCollectionSelection"), QStringLiteral("Selection"), true);
+    convertResourceColors(kalendarConfig);
+    kalendarConfig->sync();
+}
+
 void ImportCalendarJobInterface::importeventViewConfig(const KArchiveFile *file, const QString &config, const QString &filename, const QString &prefix)
 {
     copyToFile(file, config, filename, prefix);
     KSharedConfig::Ptr eventviewConfig = KSharedConfig::openConfig(config);
+    convertResourceColors(eventviewConfig);
+    eventviewConfig->sync();
+}
 
+void ImportCalendarJobInterface::convertResourceColors(const KSharedConfig::Ptr &config)
+{
     const QString resourceColorStr(QStringLiteral("Resources Colors"));
-    if (eventviewConfig->hasGroup(resourceColorStr)) {
-        KConfigGroup group = eventviewConfig->group(resourceColorStr);
+    if (config->hasGroup(resourceColorStr)) {
+        KConfigGroup group = config->group(resourceColorStr);
         const QStringList keyList = group.keyList();
         for (const QString &key : keyList) {
             const Akonadi::Collection::Id id = convertPathToId(key);
@@ -236,13 +274,11 @@ void ImportCalendarJobInterface::importeventViewConfig(const KArchiveFile *file,
             group.deleteEntry(key);
         }
     }
-
-    eventviewConfig->sync();
 }
 
 void ImportCalendarJobInterface::restoreResources()
 {
-    Q_EMIT info(i18n("Restore resources..."));
+    emitInfo(i18n("Restore resources..."));
     setProgressDialogLabel(i18n("Restore resources..."));
     increaseProgressDialog();
     QStringList listResource;
@@ -318,6 +354,11 @@ QString ImportCalendarJobInterface::configLocation() const
     return installConfigLocation();
 }
 
+QString ImportCalendarJobInterface::applicationName() const
+{
+    return QStringLiteral("[Korganizer]");
+}
+
 QString ImportCalendarJobInterface::installConfigLocation() const
 {
     return QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/');
