@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,7 +7,6 @@
 #include "exportmailjobinterface.h"
 #include "importexportmailutil.h"
 
-#include "importexportprogressindicatorbase.h"
 #include <MailCommon/FilterImporterExporter>
 
 #include <MailTransport/TransportManager>
@@ -26,16 +25,13 @@
 #include <resourceconverterimpl.h>
 
 #include <KIdentityManagement/Identity>
-#include <KIdentityManagement/IdentityManager>
 
 ExportMailJobInterface::ExportMailJobInterface(QObject *parent, Utils::StoredTypes typeSelected, ArchiveStorage *archiveStorage, int numberOfStep)
     : AbstractImportExportJob(parent, archiveStorage, typeSelected, numberOfStep)
 {
 }
 
-ExportMailJobInterface::~ExportMailJobInterface()
-{
-}
+ExportMailJobInterface::~ExportMailJobInterface() = default;
 
 bool ExportMailJobInterface::checkBackupType(Utils::StoredType type) const
 {
@@ -105,13 +101,23 @@ void ExportMailJobInterface::slotCheckBackupMails()
     mAkonadiInstanceInfo = listOfResource();
     if (checkBackupType(Utils::Mails)) {
         increaseProgressDialog();
-        setProgressDialogLabel(i18n("Backing up Mails..."));
-        QTimer::singleShot(0, this, &ExportMailJobInterface::slotWriteNextArchiveResource);
+        backupFolderAttributes();
         return;
     }
     QTimer::singleShot(0, this, &ExportMailJobInterface::slotCheckBackupResources);
 }
 
+void ExportMailJobInterface::backupFolderAttributes()
+{
+    setProgressDialogLabel(i18n("Backing up Folder Attributes..."));
+    connect(this, &ExportMailJobInterface::exportAttributeDone, this, [this]() {
+        setProgressDialogLabel(i18n("Backing up Mails..."));
+        emitInfo(i18n("Start export resource..."));
+        QTimer::singleShot(0, this, &ExportMailJobInterface::slotWriteNextArchiveResource);
+    });
+    exportFolderAttributes();
+}
+
 void ExportMailJobInterface::backupTransports()
 {
     setProgressDialogLabel(i18n("Backing up transports..."));
@@ -119,7 +125,7 @@ void ExportMailJobInterface::backupTransports()
     const QString mailtransportsStr(QStringLiteral("mailtransports"));
     const QString maitransportsrc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + mailtransportsStr;
     if (!QFileInfo::exists(maitransportsrc)) {
-        Q_EMIT info(i18n("Transports backup done."));
+        emitInfo(i18n("Transports backup done."));
     } else {
         KSharedConfigPtr mailtransportsConfig = KSharedConfig::openConfig(mailtransportsStr);
 
@@ -131,9 +137,9 @@ void ExportMailJobInterface::backupTransports()
         const bool fileAdded = archive()->addLocalFile(tmp.fileName(), Utils::transportsPath() + QStringLiteral("mailtransports"));
         delete config;
         if (fileAdded) {
-            Q_EMIT info(i18n("Transports backup done."));
+            emitInfo(i18n("Transports backup done."));
         } else {
-            Q_EMIT error(i18n("Transport file cannot be added to backup file."));
+            emitError(i18n("Transport file cannot be added to backup file."));
         }
     }
 }
@@ -151,6 +157,11 @@ void ExportMailJobInterface::slotCheckBackupResources()
     Q_EMIT jobFinished();
 }
 
+QString ExportMailJobInterface::applicationName() const
+{
+    return QStringLiteral("[KMail]");
+}
+
 void ExportMailJobInterface::backupConfig()
 {
     setProgressDialogLabel(i18n("Backing up config..."));
@@ -271,7 +282,11 @@ void ExportMailJobInterface::backupConfig()
 
         for (const QString &str : archiveList) {
             bool found = false;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             const int collectionId = str.rightRef(str.length() - archiveGroupPattern.length()).toInt(&found);
+#else
+            const int collectionId = QStringView(str).right(str.length() - archiveGroupPattern.length()).toInt(&found);
+#endif
             if (found) {
                 KConfigGroup oldGroup = archiveConfig->group(str);
                 const QString realPath = convertToFullCollectionPath(collectionId);
@@ -303,7 +318,11 @@ void ExportMailJobInterface::backupConfig()
         const QStringList templateList = templateConfig->groupList().filter(QRegularExpression(QStringLiteral("Templates #\\d+")));
         for (const QString &str : templateList) {
             bool found = false;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             const int collectionId = str.rightRef(str.length() - templateGroupPattern.length()).toInt(&found);
+#else
+            const int collectionId = QStringView(str).right(str.length() - templateGroupPattern.length()).toInt(&found);
+#endif
             if (found) {
                 KConfigGroup oldGroup = templateConfig->group(str);
                 const QString realPath = convertToFullCollectionPath(collectionId);
@@ -358,7 +377,11 @@ void ExportMailJobInterface::backupConfig()
         const QStringList folderList = kmailConfig->groupList().filter(QRegularExpression(QStringLiteral("Folder-\\d+")));
         for (const QString &str : folderList) {
             bool found = false;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             const int collectionId = str.rightRef(str.length() - folderGroupPattern.length()).toInt(&found);
+#else
+            const int collectionId = QStringView(str).right(str.length() - folderGroupPattern.length()).toInt(&found);
+#endif
             if (found) {
                 KConfigGroup oldGroup = kmailConfig->group(str);
                 ImportExportMailUtil::cleanupFolderSettings(oldGroup);
@@ -403,7 +426,11 @@ void ExportMailJobInterface::backupConfig()
             const QStringList storageList = storageGroup.keyList().filter(QRegularExpression(QStringLiteral("MessageUniqueIdForStorageModel\\d+")));
             for (const QString &str : storageList) {
                 bool found = false;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
                 const int collectionId = str.rightRef(str.length() - storageModelSelectedPattern.length()).toInt(&found);
+#else
+                const int collectionId = QStringView(str).right(str.length() - storageModelSelectedPattern.length()).toInt(&found);
+#endif
                 const QString oldValue = storageGroup.readEntry(str);
                 if (found) {
                     const QString realPath = convertToFullCollectionPath(collectionId);
@@ -522,7 +549,7 @@ void ExportMailJobInterface::backupConfig()
         delete kmailConfig;
     }
 
-    Q_EMIT info(i18n("Config backup done."));
+    emitInfo(i18n("Config backup done."));
 }
 
 void ExportMailJobInterface::backupIdentity()
@@ -566,7 +593,7 @@ void ExportMailJobInterface::backupIdentity()
                         const bool fileAdded =
                             archive()->addLocalFile(vcardFileName, Utils::identitiesPath() + QString::number(uoid) + QLatin1Char('/') + file.fileName());
                         if (!fileAdded) {
-                            Q_EMIT error(i18n("vCard file \"%1\" cannot be saved.", file.fileName()));
+                            emitError(i18n("vCard file \"%1\" cannot be saved.", file.fileName()));
                         }
                     } else {
                         group.deleteEntry(vcard);
@@ -579,9 +606,9 @@ void ExportMailJobInterface::backupIdentity()
         const bool fileAdded = archive()->addLocalFile(tmp.fileName(), Utils::identitiesPath() + QStringLiteral("emailidentities"));
         delete identityConfig;
         if (fileAdded) {
-            Q_EMIT info(i18n("Identity backup done."));
+            emitInfo(i18n("Identity backup done."));
         } else {
-            Q_EMIT error(i18n("Identity file cannot be added to backup file."));
+            emitError(i18n("Identity file cannot be added to backup file."));
         }
     }
 }
@@ -620,7 +647,7 @@ void ExportMailJobInterface::slotWriteNextArchiveResource()
                         QTimer::singleShot(0, this, &ExportMailJobInterface::slotMailsJobTerminated);
                     }
                 } else if (identifier.contains(QLatin1String("akonadi_mbox_resource_"))) {
-                    backupMailResourceFile(identifier, Utils::mailsPath()); // FIxME addressbookPath or MailPAth ???
+                    backupMailResourceFile(identifier, Utils::mailsPath()); // FIXME addressbookPath or MailPAth ???
                     QTimer::singleShot(0, this, &ExportMailJobInterface::slotMailsJobTerminated);
                 } else {
                     QTimer::singleShot(0, this, &ExportMailJobInterface::slotMailsJobTerminated);
@@ -651,7 +678,7 @@ void ExportMailJobInterface::backupResources()
                     || identifier.contains(QLatin1String("_gmail_"))) {
                     const QString errorStr = storeResources(archive(), identifier, Utils::resourcesPath());
                     if (!errorStr.isEmpty()) {
-                        Q_EMIT error(errorStr);
+                        emitError(errorStr);
                     }
                 } else {
                     qCDebug(PIMDATAEXPORTERCORE_LOG) << " resource \"" << identifier << "\" will not store";
@@ -660,5 +687,5 @@ void ExportMailJobInterface::backupResources()
         }
     }
 
-    Q_EMIT info(i18n("Resources backup done."));
+    emitInfo(i18n("Resources backup done."));
 }
