@@ -5,11 +5,8 @@
 */
 
 #include "exportmailjobinterfaceimpl.h"
-#include "importexportmailutil.h"
-
-#include "importexportprogressindicatorbase.h"
+#include "exportmailfolderattributejobimpl.h"
 #include <KIdentityManagement/IdentityManager>
-#include <KMime/Message>
 #include <MailCommon/FilterImporterExporter>
 #include <MailCommon/FilterManager>
 #include <MailCommon/MailUtil>
@@ -22,8 +19,6 @@
 #include <KZip>
 #include <QTemporaryFile>
 
-#include "pimdataexportcore_debug.h"
-
 #include "exportresourcearchivejob.h"
 #include "resourceconverterimpl.h"
 #include <QStandardPaths>
@@ -37,9 +32,7 @@ ExportMailJobInterfaceImpl::ExportMailJobInterfaceImpl(QObject *parent, Utils::S
 {
 }
 
-ExportMailJobInterfaceImpl::~ExportMailJobInterfaceImpl()
-{
-}
+ExportMailJobInterfaceImpl::~ExportMailJobInterfaceImpl() = default;
 
 Akonadi::Collection::Id ExportMailJobInterfaceImpl::convertFolderPathToCollectionId(const QString &path)
 {
@@ -89,8 +82,8 @@ void ExportMailJobInterfaceImpl::exportResourceToArchive(const QString &archiveP
     resourceJob->setIdentifier(identifier);
     resourceJob->setArchive(archive());
     resourceJob->setArchiveName(Utils::resourceMailArchiveName());
-    connect(resourceJob, &ExportResourceArchiveJob::error, this, &ExportMailJobInterfaceImpl::error);
-    connect(resourceJob, &ExportResourceArchiveJob::info, this, &ExportMailJobInterfaceImpl::info);
+    connect(resourceJob, &ExportResourceArchiveJob::error, this, &ExportMailJobInterfaceImpl::emitError);
+    connect(resourceJob, &ExportResourceArchiveJob::info, this, &ExportMailJobInterfaceImpl::emitInfo);
     connect(resourceJob, &ExportResourceArchiveJob::terminated, this, &ExportMailJobInterfaceImpl::slotMailsJobTerminated);
     connect(this, &ExportMailJobInterfaceImpl::taskCanceled, resourceJob, &ExportResourceArchiveJob::slotTaskCanceled);
     resourceJob->start();
@@ -143,9 +136,9 @@ void ExportMailJobInterfaceImpl::exportFilters()
         tmp.close();
         const bool fileAdded = archive()->addLocalFile(tmp.fileName(), Utils::configsPath() + QStringLiteral("filters"));
         if (fileAdded) {
-            Q_EMIT info(i18n("Filters backup done."));
+            emitInfo(i18n("Filters backup done."));
         } else {
-            Q_EMIT error(i18n("Filters cannot be exported."));
+            emitError(i18n("Filters cannot be exported."));
         }
     }
 }
@@ -160,3 +153,19 @@ QVector<uint> ExportMailJobInterfaceImpl::listIdentityUoid() const
     }
     return listUiod;
 }
+
+void ExportMailJobInterfaceImpl::exportFolderAttributes()
+{
+    auto job = new ExportMailFolderAttributeJobImpl(this);
+    job->setArchive(archive());
+    job->setExportInterface(this);
+    connect(job, &ExportMailFolderAttributeJobImpl::successed, this, [this]() {
+        emitInfo(i18n("Backing up Folder Attributes done."));
+        Q_EMIT exportAttributeDone();
+    });
+    connect(job, &ExportMailFolderAttributeJobImpl::failed, this, [this]() {
+        emitError(i18n("Folder Attributes cannot be exported."));
+        Q_EMIT exportAttributeDone();
+    });
+    job->start();
+}
