@@ -21,9 +21,7 @@ ExportNotesJobInterface::ExportNotesJobInterface(QObject *parent, Utils::StoredT
 {
 }
 
-ExportNotesJobInterface::~ExportNotesJobInterface()
-{
-}
+ExportNotesJobInterface::~ExportNotesJobInterface() = default;
 
 void ExportNotesJobInterface::start()
 {
@@ -45,7 +43,7 @@ void ExportNotesJobInterface::backupTheme()
     if (notesThemeDirectory.exists()) {
         const bool notesDirAdded = archive()->addLocalDirectory(notesThemeDir, Utils::dataPath() + QStringLiteral("knotes/print"));
         if (!notesDirAdded) {
-            Q_EMIT error(i18n("\"%1\" directory cannot be added to backup file.", notesThemeDir));
+            emitError(i18n("\"%1\" directory cannot be added to backup file.", notesThemeDir));
         }
     }
 }
@@ -107,7 +105,7 @@ void ExportNotesJobInterface::backupConfig()
     backupUiRcFile(QStringLiteral("knotes_part.rc"), QStringLiteral("knotes"));
     backupConfigFile(QStringLiteral("akonadi_notes_agent.notifyrc"));
     storeDirectory(QStringLiteral("/knotes/print/theme/"));
-    Q_EMIT info(i18n("Config backup done."));
+    emitInfo(i18n("Config backup done."));
 }
 
 void ExportNotesJobInterface::slotNoteJobTerminated()
@@ -120,6 +118,11 @@ void ExportNotesJobInterface::slotNoteJobTerminated()
     QTimer::singleShot(0, this, &ExportNotesJobInterface::slotWriteNextArchiveResource);
 }
 
+QString ExportNotesJobInterface::applicationName() const
+{
+    return QStringLiteral("[KNotes]");
+}
+
 void ExportNotesJobInterface::slotWriteNextArchiveResource()
 {
     if (mIndexIdentifier < mAkonadiInstanceInfo.count()) {
@@ -144,7 +147,7 @@ void ExportNotesJobInterface::slotWriteNextArchiveResource()
             QTimer::singleShot(0, this, &ExportNotesJobInterface::slotNoteJobTerminated);
         }
     } else {
-        Q_EMIT info(i18n("Resources backup done."));
+        emitInfo(i18n("Resources backup done."));
         QTimer::singleShot(0, this, &ExportNotesJobInterface::slotCheckBackupConfig);
     }
 }
