@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -56,7 +56,7 @@ void PimDataBackupRestore::setExportedInfoFileName(const QString &filename)
     mExportedInfoFileName = filename;
 }
 
-void PimDataBackupRestore::setStoredParameters(const QHash<Utils::AppsType, Utils::importExportParameters> &stored)
+void PimDataBackupRestore::setStoredParameters(const QMap<Utils::AppsType, Utils::importExportParameters> &stored)
 {
     mStored = stored;
 }
