@@ -22,9 +22,7 @@ SelectionTypeDialogTest::SelectionTypeDialogTest(QObject *parent)
     QStandardPaths::setTestModeEnabled(true);
 }
 
-SelectionTypeDialogTest::~SelectionTypeDialogTest()
-{
-}
+SelectionTypeDialogTest::~SelectionTypeDialogTest() = default;
 
 void SelectionTypeDialogTest::shouldHaveDefaultValue()
 {
@@ -32,29 +30,29 @@ void SelectionTypeDialogTest::shouldHaveDefaultValue()
     QVERIFY(dlg.isModal());
     QVERIFY(!dlg.windowTitle().isEmpty());
 
-    auto *buttonBox = dlg.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
+    auto buttonBox = dlg.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
     QVERIFY(buttonBox);
 
-    auto *mSelectionTreeWidget = dlg.findChild<SelectionTypeTreeWidget *>(QStringLiteral("mSelectionTreeWidget"));
+    auto mSelectionTreeWidget = dlg.findChild<SelectionTypeTreeWidget *>(QStringLiteral("mSelectionTreeWidget"));
     QVERIFY(mSelectionTreeWidget);
 
-    auto *mUseTemplateByDefault = dlg.findChild<QCheckBox *>(QStringLiteral("mUseTemplateByDefault"));
+    auto mUseTemplateByDefault = dlg.findChild<QCheckBox *>(QStringLiteral("mUseTemplateByDefault"));
     QVERIFY(mUseTemplateByDefault);
     QVERIFY(!mUseTemplateByDefault->isChecked());
 
-    auto *selectAll = dlg.findChild<QPushButton *>(QStringLiteral("selectAll"));
+    auto selectAll = dlg.findChild<QPushButton *>(QStringLiteral("selectAll"));
     QVERIFY(selectAll);
     QVERIFY(selectAll->isEnabled());
 
-    auto *unselectAll = dlg.findChild<QPushButton *>(QStringLiteral("unselectAll"));
+    auto unselectAll = dlg.findChild<QPushButton *>(QStringLiteral("unselectAll"));
     QVERIFY(unselectAll);
     QVERIFY(unselectAll->isEnabled());
 
-    auto *mSaveTemplate = dlg.findChild<QPushButton *>(QStringLiteral("mSaveTemplate"));
+    auto mSaveTemplate = dlg.findChild<QPushButton *>(QStringLiteral("mSaveTemplate"));
     QVERIFY(mSaveTemplate);
     QVERIFY(mSaveTemplate->isEnabled());
 
-    auto *mLoadTemplate = dlg.findChild<QPushButton *>(QStringLiteral("mLoadTemplate"));
+    auto mLoadTemplate = dlg.findChild<QPushButton *>(QStringLiteral("mLoadTemplate"));
     QVERIFY(mLoadTemplate);
     QVERIFY(mLoadTemplate->isEnabled());
 }
@@ -63,19 +61,19 @@ void SelectionTypeDialogTest::shouldHideButtons()
 {
     SelectionTypeDialog dlg(false);
     dlg.removeNotSelectedItems();
-    auto *selectAll = dlg.findChild<QPushButton *>(QStringLiteral("selectAll"));
+    auto selectAll = dlg.findChild<QPushButton *>(QStringLiteral("selectAll"));
     QVERIFY(!selectAll->isHidden());
 
-    auto *unselectAll = dlg.findChild<QPushButton *>(QStringLiteral("unselectAll"));
+    auto unselectAll = dlg.findChild<QPushButton *>(QStringLiteral("unselectAll"));
     QVERIFY(!unselectAll->isHidden());
 
-    auto *mSaveTemplate = dlg.findChild<QPushButton *>(QStringLiteral("mSaveTemplate"));
+    auto mSaveTemplate = dlg.findChild<QPushButton *>(QStringLiteral("mSaveTemplate"));
     QVERIFY(mSaveTemplate->isHidden());
 
-    auto *mLoadTemplate = dlg.findChild<QPushButton *>(QStringLiteral("mLoadTemplate"));
+    auto mLoadTemplate = dlg.findChild<QPushButton *>(QStringLiteral("mLoadTemplate"));
     QVERIFY(mLoadTemplate->isHidden());
 
-    auto *mUseTemplateByDefault = dlg.findChild<QCheckBox *>(QStringLiteral("mUseTemplateByDefault"));
+    auto mUseTemplateByDefault = dlg.findChild<QCheckBox *>(QStringLiteral("mUseTemplateByDefault"));
     QVERIFY(mUseTemplateByDefault->isHidden());
 }
 
@@ -95,13 +93,13 @@ void checkState(SelectionTypeTreeWidget *mSelectionTreeWidget, bool checked)
 void SelectionTypeDialogTest::shouldSelectAllItems()
 {
     SelectionTypeDialog dlg(false);
-    auto *mSelectionTreeWidget = dlg.findChild<SelectionTypeTreeWidget *>(QStringLiteral("mSelectionTreeWidget"));
-    auto *selectAll = dlg.findChild<QPushButton *>(QStringLiteral("selectAll"));
+    auto mSelectionTreeWidget = dlg.findChild<SelectionTypeTreeWidget *>(QStringLiteral("mSelectionTreeWidget"));
+    auto selectAll = dlg.findChild<QPushButton *>(QStringLiteral("selectAll"));
     QTest::mouseClick(selectAll, Qt::LeftButton);
 
     checkState(mSelectionTreeWidget, true);
 
-    auto *unselectAll = dlg.findChild<QPushButton *>(QStringLiteral("unselectAll"));
+    auto unselectAll = dlg.findChild<QPushButton *>(QStringLiteral("unselectAll"));
     QTest::mouseClick(unselectAll, Qt::LeftButton);
     checkState(mSelectionTreeWidget, false);
 }
