@@ -21,30 +21,28 @@ SynchronizeResourceDialogTest::SynchronizeResourceDialogTest(QObject *parent)
     QStandardPaths::setTestModeEnabled(true);
 }
 
-SynchronizeResourceDialogTest::~SynchronizeResourceDialogTest()
-{
-}
+SynchronizeResourceDialogTest::~SynchronizeResourceDialogTest() = default;
 
 void SynchronizeResourceDialogTest::shouldHaveDefaultValue()
 {
     SynchronizeResourceDialog dlg;
-    auto *buttonBox = dlg.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
+    auto buttonBox = dlg.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
     QVERIFY(buttonBox);
 
-    auto *listWidget = dlg.findChild<QListWidget *>(QStringLiteral("listresourcewidget"));
+    auto listWidget = dlg.findChild<QListWidget *>(QStringLiteral("listresourcewidget"));
     QVERIFY(listWidget);
 
-    auto *searchLine = dlg.findChild<KListWidgetSearchLine *>(QStringLiteral("listwidgetsearchline"));
+    auto searchLine = dlg.findChild<KListWidgetSearchLine *>(QStringLiteral("listwidgetsearchline"));
     QVERIFY(searchLine);
 
-    auto *label = dlg.findChild<QLabel *>(QStringLiteral("label"));
+    auto label = dlg.findChild<QLabel *>(QStringLiteral("label"));
     QVERIFY(label);
     QVERIFY(label->wordWrap());
 
-    auto *selectAll = dlg.findChild<QPushButton *>(QStringLiteral("selectall_button"));
+    auto selectAll = dlg.findChild<QPushButton *>(QStringLiteral("selectall_button"));
     QVERIFY(selectAll);
 
-    auto *unselectAll = dlg.findChild<QPushButton *>(QStringLiteral("unselectall_button"));
+    auto unselectAll = dlg.findChild<QPushButton *>(QStringLiteral("unselectall_button"));
     QVERIFY(unselectAll);
 
     QVERIFY(dlg.resources().isEmpty());
@@ -53,7 +51,7 @@ void SynchronizeResourceDialogTest::shouldHaveDefaultValue()
 void SynchronizeResourceDialogTest::shouldNotEmptyList()
 {
     SynchronizeResourceDialog dlg;
-    auto *listWidget = dlg.findChild<QListWidget *>(QStringLiteral("listresourcewidget"));
+    auto listWidget = dlg.findChild<QListWidget *>(QStringLiteral("listresourcewidget"));
     QHash<QString, QString> lst;
     lst.insert(QStringLiteral("foo"), QStringLiteral("foo"));
     lst.insert(QStringLiteral("faa"), QStringLiteral("faa"));
