@@ -5,10 +5,9 @@
 */
 
 #include "pimdataexporterconfiguredialog.h"
-#include "../widgets/pimdataexporterconfigurewidget.h"
+#include "gui/widgets/pimdataexporterconfigurewidget.h"
 #include <KConfigGroup>
 #include <KLocalizedString>
-#include <KPageWidgetModel>
 #include <KSharedConfig>
 #include <QDialogButtonBox>
 #include <QPushButton>
