@@ -16,9 +16,7 @@ FullSynchronizeResourcesJob::FullSynchronizeResourcesJob(QObject *parent)
 {
 }
 
-FullSynchronizeResourcesJob::~FullSynchronizeResourcesJob()
-{
-}
+FullSynchronizeResourcesJob::~FullSynchronizeResourcesJob() = default;
 
 void FullSynchronizeResourcesJob::setResources(const QStringList &lst)
 {
@@ -47,7 +45,7 @@ void FullSynchronizeResourcesJob::start()
     mProgressDialog->setCancelButton(nullptr);
 
     auto job = new SynchronizeResourceJob(this);
-    // Full synch
+    // Full sync
     job->setSynchronizeOnlyCollection(false);
     job->setListResources(mResources);
     connect(job, &SynchronizeResourceJob::synchronizationFinished, this, &FullSynchronizeResourcesJob::slotSynchronizeFinished);
