@@ -28,7 +28,6 @@
 #include <Akonadi/ControlGui>
 
 #include <KActionCollection>
-#include <KConfigGroup>
 #include <KFileWidget>
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -43,7 +42,7 @@
 #include <QStatusBar>
 
 #include <dialog/pimdataexporterconfiguredialog.h>
-
+#include <kwidgetsaddons_version.h>
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
 #include <KUserFeedback/NotificationPopup>
@@ -132,9 +131,11 @@ void PimDataExporterWindow::slotRestoreDone()
             connect(job, &FullSynchronizeResourcesJob::synchronizeInstanceDone, this, &PimDataExporterWindow::slotFullSyncInstanceDone);
             connect(job, &FullSynchronizeResourcesJob::synchronizeInstanceFailed, this, &PimDataExporterWindow::slotFullSyncInstanceFailed);
             job->start();
+        } else {
+            importDone();
         }
     } else {
-        slotUpdateActions(false);
+        importDone();
     }
 }
 
@@ -143,12 +144,17 @@ void PimDataExporterWindow::slotShowBackupFinishDialogInformation()
     showFinishInformation();
 }
 
-void PimDataExporterWindow::slotFullSyncFinished()
+void PimDataExporterWindow::importDone()
 {
     slotUpdateActions(false);
+    mTrayIcon->setStatus(KStatusNotifierItem::Passive);
+}
+
+void PimDataExporterWindow::slotFullSyncFinished()
+{
+    importDone();
     const QString str = i18n("Full sync finished.");
     slotAddInfo(str);
-    mTrayIcon->setStatus(KStatusNotifierItem::Passive);
     mTrayIcon->setToolTipSubTitle(str);
 }
 
@@ -227,9 +233,8 @@ void PimDataExporterWindow::setupActions(bool canZipFile)
 
 void PimDataExporterWindow::slotConfigure()
 {
-    QPointer<PimDataExporterConfigureDialog> dlg = new PimDataExporterConfigureDialog(this);
-    dlg->exec();
-    delete dlg;
+    PimDataExporterConfigureDialog dlg(this);
+    dlg.exec();
 }
 
 void PimDataExporterWindow::slotUpdateActions(bool inAction)
@@ -256,9 +261,8 @@ void PimDataExporterWindow::slotShowArchiveInformations()
         return;
     }
 
-    QPointer<ShowArchiveStructureDialog> dlg = new ShowArchiveStructureDialog(filename, this);
-    dlg->exec();
-    delete dlg;
+    ShowArchiveStructureDialog dlg(filename, this);
+    dlg.exec();
 }
 
 void PimDataExporterWindow::slotSaveLog()
@@ -350,12 +354,20 @@ void PimDataExporterWindow::slotRestoreData()
 
 void PimDataExporterWindow::loadData(const QString &filename, const QString &templateFile)
 {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    const int answer = KMessageBox::warningTwoActions(this,
+#else
     const int answer = KMessageBox::warningYesNo(this,
-                                                 i18n("Before restoring data you must close all kdepim applications. Do you want to continue?"),
-                                                 i18n("Backup"),
-                                                 KStandardGuiItem::cont(),
-                                                 KStandardGuiItem::cancel());
+#endif
+                                                      i18n("Before restoring data you must close all kdepim applications. Do you want to continue?"),
+                                                      i18n("Backup"),
+                                                      KStandardGuiItem::cont(),
+                                                      KStandardGuiItem::cancel());
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    if (answer == KMessageBox::ButtonCode::SecondaryAction) {
+#else
     if (answer == KMessageBox::No) {
+#endif
         return;
     }
 
@@ -410,16 +422,14 @@ void PimDataExporterWindow::loadData(const QString &filename, const QString &tem
 
 void PimDataExporterWindow::slotShowStructureInfos()
 {
-    QPointer<BackupFileStructureInfoDialog> dlg = new BackupFileStructureInfoDialog(this);
-    dlg->exec();
-    delete dlg;
+    BackupFileStructureInfoDialog dlg(this);
+    dlg.exec();
 }
 
 void PimDataExporterWindow::slotShowCurrentArchiveInformations()
 {
     if (!mLastArchiveFileName.isEmpty()) {
-        QPointer<ShowArchiveStructureDialog> dlg = new ShowArchiveStructureDialog(mLastArchiveFileName, this);
-        dlg->exec();
-        delete dlg;
+        ShowArchiveStructureDialog dlg(mLastArchiveFileName, this);
+        dlg.exec();
     }
 }
